|
-
+
+
+
|
@item.Lemma |
diff --git a/Lux.UI/Components/Compo/Common/CmpHeader.razor b/Lux.UI/Components/Compo/Common/CmpHeader.razor
new file mode 100644
index 00000000..480a1d90
--- /dev/null
+++ b/Lux.UI/Components/Compo/Common/CmpHeader.razor
@@ -0,0 +1,16 @@
+
+
+
+
+
+
+
+
+
+
diff --git a/Lux.UI/Components/Compo/Common/CmpHeader.razor.cs b/Lux.UI/Components/Compo/Common/CmpHeader.razor.cs
new file mode 100644
index 00000000..4d48e791
--- /dev/null
+++ b/Lux.UI/Components/Compo/Common/CmpHeader.razor.cs
@@ -0,0 +1,19 @@
+namespace Lux.UI.Components.Compo.Common
+{
+ public partial class CmpHeader
+ {
+ [Parameter]
+ public string CurrLang { get; set; } = null!;
+
+
+
+ [Parameter]
+ public EventCallback EC_LangSelected { get; set; }
+
+ private Task SaveLang()
+ {
+ return EC_LangSelected.InvokeAsync(CurrLang);
+ }
+
+ }
+}
\ No newline at end of file
diff --git a/Lux.UI/Components/Layout/MainLayout.razor b/Lux.UI/Components/Layout/MainLayout.razor
index 4ae0d026..487ac5d9 100644
--- a/Lux.UI/Components/Layout/MainLayout.razor
+++ b/Lux.UI/Components/Layout/MainLayout.razor
@@ -7,22 +7,13 @@
- @Body
+
+ @Body
+
diff --git a/Lux.UI/Components/Layout/MainLayout.razor.cs b/Lux.UI/Components/Layout/MainLayout.razor.cs
index 8a02206b..8f6d55cf 100644
--- a/Lux.UI/Components/Layout/MainLayout.razor.cs
+++ b/Lux.UI/Components/Layout/MainLayout.razor.cs
@@ -20,8 +20,23 @@ namespace Lux.UI.Components.Layout
#region Private Fields
+ private string currLang = "IT";
+
private bool navLarge = true;
#endregion Private Fields
+
+ #region Private Methods
+
+ ///
+ /// Imposta LangSel selezionata
+ ///
+ ///
+ private void SetLang(string newLang)
+ {
+ currLang = newLang;
+ }
+
+ #endregion Private Methods
}
}
\ No newline at end of file
diff --git a/Lux.UI/Components/Layout/NavMenu.razor.cs b/Lux.UI/Components/Layout/NavMenu.razor.cs
index 173e6fa7..0a92cdfb 100644
--- a/Lux.UI/Components/Layout/NavMenu.razor.cs
+++ b/Lux.UI/Components/Layout/NavMenu.razor.cs
@@ -34,11 +34,6 @@ namespace Lux.UI.Components.Layout
#endregion Protected Properties
- //private string Traduci(string lemma, string lingua = "IT")
- //{
- // return VService.Traduci(lingua, lemma);
- //}
-
#region Protected Methods
protected override void OnInitialized()
diff --git a/Lux.UI/Lux.UI.csproj b/Lux.UI/Lux.UI.csproj
index bdab922d..f3e74af3 100644
--- a/Lux.UI/Lux.UI.csproj
+++ b/Lux.UI/Lux.UI.csproj
@@ -5,7 +5,7 @@
enable
enable
aspnet-Lux.UI-a758c101-a2f4-4e38-977d-1c4887dbbd50
- 1.1.2606.0412
+ 1.1.2606.0413
diff --git a/Resources/ChangeLog.html b/Resources/ChangeLog.html
index efad7132..534d8bc9 100644
--- a/Resources/ChangeLog.html
+++ b/Resources/ChangeLog.html
@@ -1,6 +1,6 @@
LUX - Web Windows MES
- Versione: 1.1.2606.0412
+ Versione: 1.1.2606.0413
Note di rilascio:
-
diff --git a/Resources/VersNum.txt b/Resources/VersNum.txt
index d503d4e4..97b94a1a 100644
--- a/Resources/VersNum.txt
+++ b/Resources/VersNum.txt
@@ -1 +1 @@
-1.1.2606.0412
+1.1.2606.0413
diff --git a/Resources/manifest.xml b/Resources/manifest.xml
index a51961bd..7f7925a6 100644
--- a/Resources/manifest.xml
+++ b/Resources/manifest.xml
@@ -1,6 +1,6 @@
-
- 1.1.2606.0412
+ 1.1.2606.0413
http://nexus.steamware.net/repository/SWS/GPW/stable/GPW.UI.zip
http://nexus.steamware.net/repository/SWS/GPW/stable/ChangeLog.html
false
|
diff --git a/Lux.UI/Components/Pages/Vocabulary.razor.cs b/Lux.UI/Components/Pages/Vocabulary.razor.cs
index b1749e3f..ce38b029 100644
--- a/Lux.UI/Components/Pages/Vocabulary.razor.cs
+++ b/Lux.UI/Components/Pages/Vocabulary.razor.cs
@@ -53,7 +53,7 @@ namespace Lux.UI.Components.Pages
{
if (currRec != null)
{
// genero 1 rec x ogni lingua
var listNew = ListLingue.Select(x => new VocabolarioModel()
{
Lingua = x.Lingua,
@@ -90,7 +90,7 @@ namespace Lux.UI.Components.Pages
private async Task DoCloneLang(string origLang)
{
mTitle = "Attenzione";
- mMessage = "Sicuro di voler duplicare il vocabolario della lingua selezionata?\n" +
+ mMessage = "Sicuro di voler duplicare il vocabolario della LangSel selezionata?\n" +
$"Sorgente: {origLang}";
mMode = BootstrapModal.ModalMode.Confirm;
modalOpt = new();
@@ -99,7 +99,7 @@ namespace Lux.UI.Components.Pages
if (!await Modal!.ShowAsync ())
return;
// dovrebbe chiedere nuova lingua...
string destLang = "FR";
// ora duplica...
await VService.CloneAsync(origLang, destLang);
@@ -53,7 +53,7 @@ namespace Lux.UI.Components.Pages
if (currRec != null)
{
- // genero 1 rec x ogni lingua
+ // genero 1 rec x ogni LangSel
var listNew = ListLingue.Select(x => new VocabolarioModel()
{
@@ -99,7 +99,7 @@ namespace Lux.UI.Components.Pages
if (!await Modal!.ShowAsync ())
return;
- // dovrebbe chiedere nuova lingua...
+ // dovrebbe chiedere nuova LangSel...
string destLang = "FR";
// ora duplica...